<template>
  <div class="mod-config">
    <basic-container>
      <ttable
        :table="table"
        @handleSelectionChange="handleSelectionChange"
        :uploadInfo="uploadInfo"
        :isShowHide="true"
        :prelang="prelang"
        :options="options"
        :bottomOffset="125"
        :ajaxFun="ajaxFun"
        ref="partTable"
      >
        <template #toolbar></template>
      </ttable>
      <!-- 弹窗, 新增 / 修改 -->
      <table-form
        v-if="addOrUpdateVisible"
        ref="addOrUpdate"
        @refreshDataList="getData"
      ></table-form>
      <PrintLabelForm
        :currshowlist.sync="showPrintLabelForm"
        :printLabelInfo="printLabelInfo"
      />
    </basic-container>
  </div>
</template>

<script>
import { fetchList, delObj, syncIfs, syncPart } from '@/api/basic/part'
import TableForm from './part-form'
import { mapGetters } from 'vuex'
import ttable from '@/views/common/ztt-table.vue'
import { remote } from '../../../api/admin/dict'
import { dateFormat } from '@/util/date'
import PrintLabelForm from './print-label-form.vue'

export default {
  data() {
    return {
      ajaxFun: fetchList,
      addOrUpdateVisible: false,
      multipleSelection: [],
      uploadInfo: {
        // 是否展示上传EXCEL以及对应的url
        isShow: true,
        url: '/mes/part/upload'
      },
      prelang: 'operation',
      options: {
        height: 300, // 默认高度-为了表头固定
        stripe: true, // 是否为斑马纹 table
        highlightCurrentRow: false, // 是否要高亮当前行
        border: true, // 是否有纵向边框
        lazy: false, // 是否需要懒加载
        fit: true, // 列的宽度是否自撑开
        multiSelect: true, //
        seqNo: true,
        isShowHide: true, // 是否显示显影按钮
        isSearch: false, // 高级查询按钮
        defaultOrderBy: { column: 'id', direction: 'desc' }
      },
      table: {
        total: 0,
        currentPage: 1,
        pageSize: 20,
        data: [],
        // 标题
        column: [
          // 零件号
          {
            minWidth: '30',
            prop: 'partNo',
            label: '零件号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text',
            render: { fun: this.addOrUpdateHandle }
          },
          // 名称
          {
            minWidth: '120',
            prop: 'partName',
            label: '名称',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 零件类型
          {
            minWidth: '140',
            prop: 'materialType',
            label: '零件类型',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'select',
            formatter: this.getMaterialTypeType,
            optList: () => {
              return this.getMaterialTypeList()
            }
          },
          {
            minWidth: '140',
            prop: 'materialAttribute',
            label: '零件属性',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'select',
            formatter: this.getMaterialAttribute,
            optList: () => {
              return this.getMaterialAttributeList()
            }
          },
          // 单位
          {
            minWidth: '120',
            prop: 'unit',
            label: '单位',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'select',
            formatter: this.getUnit,
            optList: () => {
              return this.getUnitList()
            }
          },
          // 单位
          {
            minWidth: '120',
            prop: 'sunit',
            label: '单位2',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'select',
            formatter: this.getUnit,
            optList: () => {
              return this.getUnitList()
            }
          },
          // 描述
          {
            minWidth: '140',
            prop: 'description',
            label: '备注',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 一级分类
          {
            minWidth: '120',
            prop: 'assortment',
            label: '一级分类',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'select',
            optList: () => {
              return this.getAssortment()
            }
          },
          // 二级分类
          {
            minWidth: '140',
            prop: 'category',
            label: '二级分类',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'select',
            optList: () => {
              return this.getCategory()
            }
          },
          // 三级分类
          {
            minWidth: '140',
            prop: 'threeLevelClassification',
            label: '三级分类',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'select',
            optList: () => {
              return this.getThreeLevelClassification()
            }
          },
          // 规格
          {
            minWidth: '140',
            prop: 'specs',
            label: '规格',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 型号
          {
            minWidth: '140',
            prop: 'partModel',
            label: '型号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 电压等级
          {
            minWidth: '140',
            prop: 'voltageLevel',
            label: '电压等级',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 特性代号1
          {
            minWidth: '140',
            prop: 'characteristic1',
            label: '特性代号1',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 特性代号2
          {
            minWidth: '140',
            prop: 'characteristic2',
            label: '特性代号2',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 特性代号3
          {
            minWidth: '140',
            prop: 'characteristic3',
            label: '特性代号3',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // IFS启用批次管理  !!this.permissions.basic_has_ifs
          {
            minWidth: '140',
            prop: 'lotTrackingIfs',
            label: 'IFS启用批次管理',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'select',
            formatter: this.formatLotTrackingIfs,
            optList: () => {
              return this.lotTrackingIfsOptions
            }
          },
          // 版本号
          {
            minWidth: '140',
            prop: 'engChgLevel',
            label: '版本号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 计划方法
          {
            minWidth: '140',
            prop: 'planningMethod',
            label: '计划方法',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'select',
            formatter: this.formatPlanningMethodIfs,
            optList: () => {
              return this.planningMethodOptions
            }
          },
          // 图号
          {
            minWidth: '140',
            prop: 'drawingNumber',
            label: '图号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // EAN编码
          {
            minWidth: '120',
            prop: 'ean',
            label: 'EAN编码',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 零件族
          {
            minWidth: '120',
            prop: 'partFamilyName',
            label: '零件族',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 检验员
          {
            minWidth: '140',
            prop: 'examiner',
            label: '检验员',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'select',
            optList: () => {
              return this.getExaminerOptions()
            }
          },
          // 产品名称
          {
            minWidth: '140',
            prop: 'prodName',
            label: '产品名称',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 节距
          {
            minWidth: '140',
            prop: 'partPitch',
            label: '节距',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          }
        ],
        toolbar: [
          {
            text: '新增',
            type: 'primary',
            fun: this.addOrUpdateHandle
          },
          {
            text: '同步ERP',
            type: 'primary',
            fun: this.syncIfs,
            loading: false
          },
          {
            text: '大标签',
            type: 'primary',
            fun: this.printLabel,
            loading: false
          }
        ],
        operator: [
          {
            text: '删除',
            type: 'text',
            size: 'small',
            fun: this.deleteHandle
          }
        ],
        operatorConfig: {
          fixed: 'right',
          label: '操作',
          width: 100,
          minWidth: 100
        }
      },
      unitList: [],
      materialTypeList: [],
      materialAttributeList: [],
      categoryList: [],
      assortmentList: [],
      lotTrackingIfsOptions: [
        { value: false, label: '否' },
        { value: true, label: '是' }
      ],
      planningMethodOptions: [],
      threeLevelClassificationOptions: [],
      showPrintLabelForm: false,
      printLabelInfo: null,
      examinerOptions: []
    }
  },
  components: {
    TableForm,
    ttable,
    PrintLabelForm
  },
  created() {
    this.table.column.find((e) => e.label === 'IFS启用批次管理').isTrue = false
    this.table.column.find((e) => e.label === '计划方法').isTrue = false
    this.getUnitType('unit')
    this.getMaterialType('material_type')
    this.getCategoryType('category')
    this.getAssortmentType('assortment')
    this.getPlanningMethodType('planning_method_type')
    this.getThreeLevelClassificationType('three_classification_type')
    this.getMaterialAttributeType()
    this.getExaminerDict('examiner_type')
  },
  computed: {
    ...mapGetters(['permissions'])
  },
  methods: {
    // 获取数据列表
    getData() {
      this.$refs.partTable.getDataList()
    },
    // 新增 / 修改
    addOrUpdateHandle(row) {
      this.addOrUpdateVisible = true
      this.$nextTick(() => {
        this.$refs.addOrUpdate.init(row == null ? null : row.id)
      })
    },
    // 删除
    deleteHandle(row) {
      this.$confirm('是否确认零件名为:' + row.partName, '提示', {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        closeOnClickModal: false,
        type: 'warning'
      })
        .then(function() {
          return delObj(row.id)
        })
        .then((data) => {
          this.$message.success('删除成功')
          this.getData()
        })
    },
    /**
     * 获取字典显示名称并缓存
     */
    getUnitType(type) {
      remote(type).then((response) => {
        const code = response.data.code
        if (code === 0) {
          const _data = response.data.data
          this.unitList = _data
        }
      })
    },
    getMaterialType(type) {
      remote(type).then((response) => {
        const code = response.data.code
        if (code === 0) {
          const _data = response.data.data
          this.materialTypeList = _data
        }
      })
    },
    getMaterialAttributeType() {
      remote('material_attribute').then((response) => {
        const code = response.data.code
        if (code === 0) {
          const _data = response.data.data
          this.materialAttributeList = _data
        }
      })
    },
    getCategoryType(type) {
      remote(type).then((response) => {
        const code = response.data.code
        if (code === 0) {
          const _data = response.data.data
          this.categoryList = _data
        }
      })
    },
    getAssortmentType(type) {
      remote(type).then((response) => {
        const code = response.data.code
        if (code === 0) {
          const _data = response.data.data
          this.assortmentList = _data
        }
      })
    },
    getPlanningMethodType(type) {
      remote(type).then((response) => {
        const code = response.data.code
        if (code === 0) {
          const _data = response.data.data
          this.planningMethodOptions = _data
        }
      })
    },
    getThreeLevelClassificationType(type) {
      remote(type).then((response) => {
        const code = response.data.code
        if (code === 0) {
          const _data = response.data.data
          this.threeLevelClassificationOptions = _data
        }
      })
    },
    getExaminerDict(type) {
      remote(type).then((response) => {
        const code = response.data.code
        if (code === 0) {
          const _data = response.data.data
          this.examinerOptions = _data
        }
      })
    },
    getUnit(row, column, cellValue) {
      this.unitList.forEach((obj) => {
        if (obj.value == cellValue) {
          cellValue = obj.label
        }
      })
      return cellValue
    },
    getMaterialTypeType(row, column, cellValue) {
      this.materialTypeList.forEach((obj) => {
        if (obj.value == cellValue) {
          cellValue = obj.label
        }
      })
      return cellValue
    },
    getMaterialAttribute(row, column, cellValue) {
      this.materialAttributeList.forEach((obj) => {
        if (obj.value == cellValue) {
          cellValue = obj.label
        }
      })
      return cellValue
    },
    // 单位下拉框查询
    getUnitList() {
      return this.unitList
    },
    // 零件类型下拉框查询
    getMaterialTypeList() {
      return this.materialTypeList
    },
    // 零件属性下拉框查询
    getMaterialAttributeList() {
      return this.materialAttributeList
    },
    // 二级分类下拉框查询
    getCategory() {
      return this.categoryList
    },
    // 二级分类下拉框查询
    getAssortment() {
      return this.assortmentList
    },
    // 三级分类下拉框查询
    getThreeLevelClassification() {
      return this.threeLevelClassificationOptions
    },
    // 检验员
    getExaminerOptions() {
      return this.examinerOptions
    },
    formatLotTrackingIfs(row, column, cellValue) {
      this.lotTrackingIfsOptions.forEach((obj) => {
        if (obj.value === cellValue) {
          cellValue = obj.label
        }
      })
      return cellValue
    },
    formatPlanningMethodIfs(row, column, cellValue) {
      this.planningMethodOptions.forEach((obj) => {
        if (obj.value === cellValue) {
          cellValue = obj.label + '、 ' + obj.description
        }
      })
      return cellValue
    },
    handleSelectionChange(val) {
      this.multipleSelection = val
    },
    // 零件同步至ifs
    // syncIfs() {
    //   if (this.multipleSelection.length > 0) {
    //     const toolbars = this.table.toolbar
    //     toolbars[1].loading = true
    //     const ids = []
    //     this.multipleSelection.forEach((item) => {
    //       ids.push(item.id)
    //     })
    //
    //     syncIfs(ids)
    //       .then((res) => {
    //         const data = res.data
    //         if (data.code === 0) {
    //           this.$message.success('同步ERP成功')
    //         } else {
    //           this.$message.error('同步ERP失败')
    //         }
    //         toolbars[1].loading = false
    //       })
    //       .catch(() => {
    //         toolbars[1].loading = false
    //       })
    //   } else {
    //     this.$message.warning('请先选择零件，再进行同步！')
    //   }
    // },
    syncIfs() {
      syncPart({})
        .then((res) => {
          const data = res.data
          if (data.code === 0) {
            this.$message.success('开始同步')
          } else {
            this.$message.error('同步ERP失败')
          }
        })
        .catch((e) => {
          // this.$message.error('同步ERP失败:' + e)
        })
    },
    printLabel() {
      if (this.multipleSelection && this.multipleSelection.length > 0) {
        if (this.multipleSelection && this.multipleSelection.length === 1) {
          this.showPrintLabelForm = true
          this.printLabelInfo = {
            partId: null,
            partNo: this.multipleSelection[0].partNo,
            partName: this.multipleSelection[0].partName,
            outBatchNo: null,
            ifsBatchNo: null,
            productQty: null,
            lotTrackingIfs: this.multipleSelection[0].lotTrackingIfs,
            unit: this.multipleSelection[0].unit,
            customerOrderNo: null,
            customerName: null,
            operationName: null,
            workstationName: null,
            grossWeight: null,
            netWeight: null,
            theoryWeight: null,
            segmentDesc: null,
            reelNumber: null,
            reelWeight: null,
            nowTime: dateFormat(new Date()),
            productionPerson: null,
            remark: null,
            startMeterMark: null,
            endMeterMark: null
          }
        } else {
          this.$message.error('只能选择一条零件')
        }
      } else {
        this.$message.error('请选择零件')
      }
    }
  }
}
</script>
